import 'package:flutter/material.dart';

// ignore: must_be_immutable
class CustomDialog extends StatelessWidget {

  String _title;
  String _content;
  String _buttonOneText;
  String _buttonTwoText;
  bool _showButtonOne;
  bool _showButtonTwo;
  Function _buttonOne;
  Function _buttonTwo;

  CustomDialog(
      {String title,
        String content,
        bool showButtonOne = true,
        Function buttonOne,
        String buttonOneText = "buttonOne",
        bool showButtonTwo = true,
        Function buttonTwo,
        String buttonTwoText = "buttonTwo"}) {
    this._title = title;
    this._content = content;
    this._buttonOne = buttonOne;
    this._buttonTwo = buttonTwo;
    this._buttonOneText = buttonOneText;
    this._buttonTwoText = buttonTwoText;
    this._showButtonOne = showButtonOne;
    this._showButtonTwo = showButtonTwo;
  }

  static const double padding = 16.0;
  static const double avatarRadius = 66.0;


  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape:
      RoundedRectangleBorder(borderRadius: BorderRadius.circular(padding)),
      elevation: 0.0,
      backgroundColor: Colors.transparent,
      child: dialogContent(context),
    );
  }

  dialogContent(BuildContext context) {
    return Stack(
      children: <Widget>[
        mainPart(context),
        circleIcon(),
      ],
    );
  }

  Widget mainPart(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
        top: avatarRadius + padding,
        bottom: padding,
        left: padding,
        right: padding,
      ),
      margin: EdgeInsets.only(top: avatarRadius),
      decoration: new BoxDecoration(
        color: Colors.white,
        shape: BoxShape.rectangle,
        borderRadius: BorderRadius.circular(padding),
        boxShadow: [
          BoxShadow(
            color: Colors.black26,
            blurRadius: 10.0,
            offset: const Offset(0.0, 10.0),
          ),
        ],
      ),
      child: Column(
        mainAxisSize: MainAxisSize.min, // To make the card compact
        children: <Widget>[
          Text(
            this._title,
            style: TextStyle(
              fontSize: 24.0,
              fontWeight: FontWeight.w700,
            ),
          ),
          SizedBox(height: 16.0),
          Text(
            this._content,
            textAlign: TextAlign.center,
            style: TextStyle(
              fontSize: 16.0,
            ),
          ),
          SizedBox(height: 24.0),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              this._showButtonTwo
                  ? customButton(context, this._buttonTwo, this._buttonTwoText)
                  : Container(),
              this._showButtonOne
                  ? customButton(context, this._buttonOne, this._buttonOneText)
                  : Container(),
            ],
          ),
        ],
      ),
    );
  }

  Widget circleIcon() {
    return Positioned(
      left: padding,
      right: padding,
      child: CircleAvatar(
        backgroundColor: Colors.blueAccent,
        radius: avatarRadius,
      ),
    );
  }

  Widget customButton(
      BuildContext context, Function _function, String buttonText) {
    return Align(
      alignment: Alignment.bottomRight,
      child: FlatButton(
        onPressed: () {
          _function();
          Navigator.of(context).pop(); // To close the dialog
        },
        child: Text(buttonText),
      ),
    );
  }
}
